====
List
====

The following methods are available under the `DataTypeExpr.list` attribute.

.. currentmodule:: polars
.. autosummary::
   :toctree: api/
   :template: autosummary/accessor_method.rst

    DataTypeExpr.list.inner_dtype
